@@ -30,13 +30,13 @@ impl Entry {
             imports: Default::default(),
         };
         if is_any_target || is_web_target {
-            v.imports.insert("web.timers".into());
-            v.imports.insert("web.immediate".into());
-            v.imports.insert("web.dom.iterable".into());
+            v.imports.insert("web.timers");
+            v.imports.insert("web.immediate");
+            v.imports.insert("web.dom.iterable");
         }
 
         if regenerator {
-            v.imports.insert("regenerator-runtime/runtime.js".into());
+            v.imports.insert("regenerator-runtime/runtime.js");
         }
 
         v
@@ -50,7 +50,7 @@ impl Entry {
         }
 
         for (feature, version) in BUILTINS.iter() {
-            self.add_inner(&feature, *version);
+            self.add_inner(feature, *version);
         }
 
         true
@@ -87,42 +87,36 @@ impl Fold for Entry {
         items.move_flat_map(|item| {
             let item: ModuleItem = item.fold_with(self);
 
-            match &item {
-                ModuleItem::Stmt(Stmt::Expr(ExprStmt { expr, .. })) => match &**expr {
-                    Expr::Call(CallExpr {
-                        callee: Callee::Expr(callee),
-                        ref args,
+            if let ModuleItem::Stmt(Stmt::Expr(ExprStmt { expr, .. })) = &item {
+                if let Expr::Call(CallExpr {
+                    callee: Callee::Expr(callee),
+                    ref args,
+                    ..
+                }) = &**expr
+                {
+                    if let Expr::Ident(Ident {
+                        sym: js_word!("require"),
                         ..
-                    }) => match &**callee {
-                        Expr::Ident(Ident {
-                            sym: js_word!("require"),
-                            ..
-                        }) => {
-                            if args.len() == 1
-                                && match &args[0] {
-                                    ExprOrSpread { spread: None, expr } => match &**expr {
-                                        Expr::Lit(Lit::Str(s)) => {
-                                            s.value == *"core-js"
-                                                || s.value == *"@swc/polyfill"
-                                                || s.value == *"@babel/polyfill"
-                                        }
-                                        _ => false,
-                                    },
-                                    _ => false,
-                                }
-                            {
-                                if self.add_all("@swc/polyfill") {
-                                    return None;
+                    }) = &**callee
+                    {
+                        if args.len() == 1
+                            && if let ExprOrSpread { spread: None, expr } = &args[0] {
+                                if let Expr::Lit(Lit::Str(s)) = &**expr {
+                                    s.value == *"core-js"
+                                        || s.value == *"@swc/polyfill"
+                                        || s.value == *"@babel/polyfill"
+                                } else {
+                                    false
                                 }
+                            } else {
+                                false
                             }
+                            && self.add_all("@swc/polyfill")
+                        {
+                            return None;
                         }
-
-                        _ => {}
-                    },
-                    _ => {}
-                },
-
-                _ => {}
+                    }
+                }
             }
 
             Some(item)
